Documentation
¶
Index ¶
Constants ¶
const CacheLineSize = int(unsafe.Sizeof(cpu.CacheLinePad{}))
Variables ¶
This section is empty.
Functions ¶
func JsonToYaml ¶
JsonToYaml converts JSON data to YAML data
func YamlToJson ¶
YamlToJson converts YAML data to JSON data
Types ¶
type Queue ¶
type Queue[T any] struct { // contains filtered or unexported fields }
func (*Queue[T]) Pop ¶
Pop Don't usePreviously used a different package https://github.com/zeroflucs-given/generics/tree/main/collections So temporarily keeping the old method names for backward compatibility Deprecated: Use Dequeue instead
func (*Queue[T]) Push ¶
Push Don't usePreviously used a different package https://github.com/zeroflucs-given/generics/tree/main/collections So temporarily keeping the old method names for backward compatibility Deprecated: Use Enqueue instead
type Stack ¶
type Stack[T any] struct { // contains filtered or unexported fields }
func (*Stack[T]) MarshalJSON ¶
func (*Stack[T]) RawArrayCopy ¶
func (s *Stack[T]) RawArrayCopy() []T
type TriState ¶
type TriState struct {
// contains filtered or unexported fields
}
func (TriState) IsSetToFalse ¶
func (TriState) IsSetToTrue ¶
Click to show internal directories.
Click to hide internal directories.